@@ -1,9 +1,12 @@
 package Apache::Session::Browseable::DBI;
 
 use strict;
-use DBI;
 
-our $VERSION = '0.1';
+use DBI;
+use Apache::Session;
+
+our $VERSION = '0.2';
+our @ISA     = qw(Apache::Session);
 
 sub searchOn {
     my ( $class, $args, $selectField, $value, @fields ) = @_;
@@ -35,7 +38,7 @@ sub searchOn {
             sub {
                 my $entry = shift;
                 my $id    = shift;
-                return undef unless ( $entry->{selectField} eq $value );
+                return undef unless ( $entry->{$selectField} eq $value );
                 if (@fields) {
                     $res{$id}->{$_} = $entry->{$_} foreach (@fields);
                 }
